@@ -257,7 +257,7 @@ int32_t SPVM_STRING_BUFFER_add_float(SPVM_STRING_BUFFER* string_buffer, float va
 
   int32_t id = string_buffer->length;
   
-  int32_t max_length = 20 + 1;
+  int32_t max_length = 100;
   
   int32_t new_max_length = string_buffer->length + max_length;
   
@@ -266,14 +266,10 @@ int32_t SPVM_STRING_BUFFER_add_float(SPVM_STRING_BUFFER* string_buffer, float va
   
   char* start_ptr = string_buffer->buffer + string_buffer->length;
   
-  int32_t write_length = sprintf(string_buffer->buffer + string_buffer->length, "%.9g", value);
+  int32_t write_length = sprintf(string_buffer->buffer + string_buffer->length, "%a", value);
   
   string_buffer->length += write_length;
   
-  if (!(strchr(start_ptr, '.') || strchr(start_ptr, 'e') || strchr(start_ptr, 'E'))) {
-    SPVM_STRING_BUFFER_add(string_buffer, ".0");
-  }
-  
   return id;
 }
 
@@ -281,7 +277,7 @@ int32_t SPVM_STRING_BUFFER_add_double(SPVM_STRING_BUFFER* string_buffer, double
 
   int32_t id = string_buffer->length;
   
-  int32_t max_length = 20;
+  int32_t max_length = 100;
   
   int32_t new_max_length = string_buffer->length + max_length;
   
@@ -290,14 +286,10 @@ int32_t SPVM_STRING_BUFFER_add_double(SPVM_STRING_BUFFER* string_buffer, double
 
   char* start_ptr = string_buffer->buffer + string_buffer->length;
   
-  int32_t write_length = sprintf(string_buffer->buffer + string_buffer->length, "%.17g", value);
+  int32_t write_length = sprintf(string_buffer->buffer + string_buffer->length, "%a", value);
   
   string_buffer->length += write_length;
 
-  if (!(strchr(start_ptr, '.') || strchr(start_ptr, 'e') || strchr(start_ptr, 'E'))) {
-    SPVM_STRING_BUFFER_add(string_buffer, ".0");
-  }
-  
   return id;
 }
 
